TODO fix file

# `lute3-langname`

A LangName parser for Lute (`lute3`) ... TODO notes here.

## Installation

See the [Lute manual](https://luteorg.github.io/lute-manual/install/plugins.html).

## Usage

When this parser is installed, you can add "LangName" as a
language to Lute, which comes with a simple story.
